pilas.mundo.Mundo

Package pilas :: Module mundo :: Class Mundo |
[hide private]
[frames] | no frames]

# Class Mundo

source code

    object --+
             |
            Mundo

Representa un objeto unico que mantiene en funcionamiento al motor.

Mundo tiene como responsabilidad iniciar los componentes del motor y mantener el bucle de juego.

Instance Methods | [hide private]
__init__(self, motor, ancho, alto, titulo, rendimiento=60, gravedad=`(`0`,` -10`)`, pantalla_completa=False) x.__init__(...) initializes x; see help(type(x)) for signature | source code
agregar_tarea(self, time_out, funcion, *parametros) | source code
agregar_tarea_siempre(self, time_out, function, *params) | source code
agregar_tarea_una_vez(self, time_out, function, *params) | source code
crear_motor_fisica(self) | source code
deshabilitar_musica(self, estado=True) | source code
deshabilitar_sonido(self, estado=True) | source code
ejecutar_bucle_principal(self, ignorar_errores=False) Mantiene en funcionamiento el motor completo. | source code
get_camara_deprecated(self) | source code
get_colisiones_deprecated(self) | source code
get_control_deprecated(self) | source code
get_tareas_deprecated(self) | source code
reiniciar(self) | source code
terminar(self) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
| camara
| colisiones
| control
| tareas
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, motor, ancho, alto, titulo, rendimiento=60, gravedad=`(`0`,` -10`)`, pantalla_completa=False) (Constructor) | source code
x.__init__(...) initializes x; see help(type(x)) for signature Overrides: object.__init__ (inherited documentation)

Property Details | [hide private]

### camara Get Method: get_camara_deprecated(self)

### colisiones Get Method: get_colisiones_deprecated(self)

### control Get Method: get_control_deprecated(self)

### tareas Get Method: get_tareas_deprecated(self)